@@ -91,7 +91,7 @@ has output_file_name =>
 	required => 0,
 );
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 # ------------------------------------------------
 
@@ -109,6 +109,7 @@ sub BUILD
 				maxlevel       => $self -> maxlevel,
 				message_layout => '%m',
 				minlevel       => $self -> minlevel,
+				utf8           => 1,
 			}
 		);
 	}
@@ -124,7 +125,7 @@ sub get_encoding
 	my($self, %args) = @_;
 	my($encoding)    = $args{encoding} || $self -> encoding;
 
-	return $encoding ? ":$encoding" : '';
+	return $encoding ? ":encoding($encoding)" : '';
 
 } # End of get_encoding.
 
@@ -231,7 +232,11 @@ sub test
 	my(@data)    = grep{! /#/} read_file($self -> input_file_name, binmode => $self -> get_encoding(%args) );
 	my($handler) = MarpaX::Languages::SVG::Parser::SAXHandler -> new(logger => $self -> logger);
 
-	$handler -> run_marpa(attribute => $self -> attribute, value => join('', @data) );
+	# The start_document() call emulates XML input, in order to partially initialize to action class.
+	# I say partially because the other part takes place in the handler's method init_marpa().
+
+	$handler -> start_document;
+	$handler -> run_marpa($self -> attribute, join('', @data) );
 	$self -> items -> push(@{$handler -> items -> print});
 	$self -> report;
 
@@ -620,6 +625,14 @@ These are all shipped in the data/ directory.
 
 =over 4
 
+=item o *.log
+
+The logs of running this on each *.svg file:
+
+	shell> perl -Ilib scripts/parse.file.pl -i data/ellipse.02.svg -max debug > data/ellipse.02.log
+
+The *.log files are generated by scripts/svg2.log.pl.
+
 =item o circle.01.csv
 
 Output from scripts/parse.file.pl
@@ -651,12 +664,6 @@ It was generated by scripts/bnf2graph.pl.
 
 Test data for scripts/parse.file.pl
 
-=item o ellipse.02.log
-
-The log of running:
-
-	shell> perl -Ilib scripts/parse.file.pl -i data/ellipse.02.svg -max debug > data/ellipse.02.log
-
 =item o line.01.svg
 
 Test data for scripts/parse.file.pl
@@ -796,10 +803,22 @@ This is the script you'll probably use most frequently. Run with '-h' for help.
 
 This lets me quickly proof-read edits to the docs.
 
+=item o svg2log.pl
+
+Runs parse.file.pl on each data/*.svg file and saves the output in data/*.log.
+
 =item o synopsis.pl
 
 The code as per the L</Synopsis>.
 
+=item o t/test.fake.data.t
+
+A test script. It parses data/*.dat, which are not SVG files, but just contain attribute value data.
+
+=item o t/test.real.data.t
+
+A test script. It parses data/*.svg, which are SVG files, and compares them to the shipped files data/*.log.
+
 =item o test.file.pl
 
 This runs the code on a single test file (data/*.dat, I<not> an svg file). Try:
@@ -812,10 +831,6 @@ This runs the code on a set of files (data/d.*.dat, data/points.*.dat or data/tr
 
 	shell> perl -Ilib scripts/test.fileset.pl -a transform -max debug
 
-=item o t/runner.t
-
-A test script.
-
 =item o t/version.t
 
 A test script.
@@ -824,6 +839,8 @@ A test script.
 
 =head1 FAQ
 
+See also L<MarpaX::Languages::SVG::Parser::Actions/FAQ>.
+
 =head2 What exactly does this module do?
 
 It parses SVG files (using L<XML::SAX|XML::SAX::Base>), and applies special parsing (using L<Marpa::R2>) to certain
@@ -1008,9 +1025,12 @@ The C<name> field in this case will be a counter of parameters for the preceedin
 
 =item o command
 
-The C<value> is one of the drawing commands defined by SVG.
+The C<name> field is the letter (Mm, ..., Zz) for the command itself. In these cases, the C<value> is '-'.
 
-The C<name> field is '-'.
+Note: As of V 1.01, in the hashref returned by the C<action> sub C<command>, the C<value> is actually an arrayref
+of the commands parameters. In V 1.00, the C<name> was '-' and the C<value> was the commany letter. This change
+was made when I stopped pushing hashrefs onto a stack, and converted the return value of the sub from scalar to
+hashref.
 
 =item o content
 
@@ -1086,44 +1106,44 @@ Here is a fragment of data/ellipse.02.svg:
 
 And here is the output from the built-in reporting mechanism (see data/ellipse.02.log):
 
-	Item  Type              Name              Value
-	   1  tag               svg               open
-	...
-	  23  tag               path              open
-	  24  raw               d                 M300,200 h-150 a150,150 0 1,0 150,-150 z
-	  25  command           -                 M
-	  26  float             1                 300
-	  27  float             2                 200
-	  28  command           -                 h
-	  29  float             1                 -150
-	  30  command           -                 a
-	  31  float             1                 150
-	  32  float             2                 150
-	  33  integer           3                 0
-	  34  boolean           4                 1
-	  35  boolean           5                 0
-	  36  float             6                 150
-	  37  float             7                 -150
-	  38  command           -                 z
-	  39  attribute         fill              red
-	  40  attribute         stroke            blue
-	  41  attribute         stroke-width      5
-	  42  content           path
-	  43  tag               path              close
-	...
-	  66  tag               svg               close
+	Item  Type        Name              Value
+	   1  tag         svg               open
+		...
+	  27  tag         path              open
+	  28  raw         d                 M300,200 h-150 a150,150 0 1,0 150,-150 z
+	  29  command     M                 -
+	  30  float       1                 300
+	  31  float       2                 200
+	  32  command     h                 -
+	  33  float       1                 -150
+	  34  command     a                 -
+	  35  float       1                 150
+	  36  float       2                 150
+	  37  integer     3                 0
+	  38  boolean     4                 1
+	  39  boolean     5                 0
+	  40  float       6                 150
+	  41  float       7                 -150
+	  42  command     z                 -
+	  43  attribute   fill              red
+	  44  attribute   stroke            blue
+	  45  attribute   stroke-width      5
+	  46  content     path
+	  47  tag         path              close
+		...
+	  66  tag         svg               close
 
 Let's go thru it:
 
 =over 4
 
-=item o Item 23 is the open tag for the path
+=item o Item 27 is the open tag for the path
 
 	Type:  tag
 	Name:  path
 	Value: open
 
-=item o Item 24 is the path's 1st attribute, 'd'
+=item o Item 28 is the path's 1st attribute, 'd'
 
 	Type:  raw
 	Name:  d
@@ -1135,58 +1155,58 @@ output of that value.
 Note: Attributes are reported in sorted order, but the parameters after parsing the attributes' values cannot be,
 because drawing the coordinates of the value is naturally order-dependent.
 
-=item o Item 25
+=item o Item 29
 
 	Type:   command
-	Name:   '-'
-	Values: M
+	Name:   M
+	Values: '-'
 
 This in turn is followed by its respective parameters, if any.
 
 Note: 'Z' and 'z' have no parameters.
 
-=item o Item 26 .. 27
+=item o Item 30 .. 31
 
 Two floats. Commas are discarded in the parsing of all special values.
 
 Also, you'll notice they are numbered for your convenience by the C<name> key in their hashrefs.
 
-=item o Item 28
+=item o Item 32
 
 	Type:   command
-	Name:   '-'
-	Values: h
+	Name:   h
+	Values: '-'
 
-=item o Item 29
+=item o Item 33
 
 This is the float which belongs to 'h'.
 
-=item o Item 30
+=item o Item 34
 
 	Type:   command
-	Name:   '-'
-	Values: a
+	Name:   a
+	Values: '-'
 
-=item o Items 31 .. 37
+=item o Items 35 .. 41
 
 The 7 parameters of the 'a' command. You'll notice the parser calls 0 an integer rather than a float.
 SVG does not care, and neither should you. But, since the code knows it is, it might as well tell you.
 
 The two Boolean  flags are picked up explicitly, and the code tells you that, too.
 
-=item o Item 38
+=item o Item 42
 
 	Type:   command
-	Name:   '-'
-	Values: z
+	Name:   z
+	Values: '-'
 
 As stated, it has no following parameters.
 
-=item o Items 39 .. 42
+=item o Items 43 .. 46
 
 The remaining attributes of the 'path'. None of these are treated specially.
 
-=item o Item 43 is the close tag for the path
+=item o Item 47 is the close tag for the path
 
 	Type:  tag
 	Name:  path
@@ -1223,7 +1243,9 @@ Without this pragma, data/utf8.01.svg gives you the dread 'Wide character in pri
 
 The pragma is not in the module because it's global, and the end user's program may not want it at all.
 
-Lastly, it turns out L<Log::Handler> has an undocumented attribute {utf8 => 1}, which I have not used.
+Lastly, I have unilaterally set the utf8 attribute used by L<Log::Handler>. This is harmless for non-utf-8 file,
+and is vital for data/utf8.01.svg and similar end-user files. It allows the log output (STDOUT) to be redirected.
+And indeed, this is what some of the tests do.
 
 =head1 TODO
 
